@@ -112,17 +112,16 @@ gdvd_button_new_dialog_callback(GtkWidget *widget, int id, GalDefineViewsDialog
 			     "factory", &factory,
 			     NULL);
 		if (name && factory) {
-			gchar *dup_of_name = g_strdup(name);
-			g_strchomp(dup_of_name);
-			if (*dup_of_name != '\0') {
-				GtkWidget *editor;
-				view = gal_view_factory_new_view(factory, dup_of_name);
+			g_strchomp(name);
+			if (*name != '\0') {
+				view = gal_view_factory_new_view(factory, name);
 				gal_define_views_model_append(GAL_DEFINE_VIEWS_MODEL(dialog->model), view);
 				gal_view_edit(view, GTK_WINDOW (dialog));
 				g_object_unref(view);
 			}
-			g_free(dup_of_name);
 		}
+		g_object_unref(factory);
+		g_free(name);
 		break;
 	}
 	gtk_widget_destroy (widget);
@@ -176,6 +175,7 @@ gdvd_button_delete_callback(GtkWidget *widget, GalDefineViewsDialog *dialog)
 
 }
 
+#if 0
 static void
 gdvd_button_copy_callback(GtkWidget *widget, GalDefineViewsDialog *dialog)
 {
@@ -193,6 +193,7 @@ gdvd_button_copy_callback(GtkWidget *widget, GalDefineViewsDialog *dialog)
 	}
 
 }
+#endif
 
 static void
 gdvd_connect_signal(GalDefineViewsDialog *dialog, char *widget_name, char *signal, GCallback handler)
@@ -205,6 +206,24 @@ gdvd_connect_signal(GalDefineViewsDialog *dialog, char *widget_name, char *signa
 		g_signal_connect(widget, signal, handler, dialog);
 }
 
+static void
+etable_selection_change_forall_cb (int row, GalDefineViewsDialog *dialog)
+{
+	if (row != -1) {
+		GalViewCollectionItem *item = gal_view_collection_get_view_item (dialog->collection, row);
+
+		if (item)
+			gtk_widget_set_sensitive (glade_xml_get_widget (dialog->gui, "button-delete"),
+						  !item->built_in);
+	}
+}
+
+static void
+etable_selection_change (ETable *etable, GalDefineViewsDialog *dialog)
+{
+	e_table_selected_row_foreach (etable, (EForeachFunc) etable_selection_change_forall_cb, dialog);
+}
+
 static void
 gal_define_views_dialog_init (GalDefineViewsDialog *dialog)
 {
@@ -214,7 +233,7 @@ gal_define_views_dialog_init (GalDefineViewsDialog *dialog)
 
 	dialog->collection = NULL;
 
-	gui = glade_xml_new (GAL_GLADEDIR "/gal-define-views.glade", NULL, PACKAGE);
+	gui = glade_xml_new (GAL_GLADEDIR "/gal-define-views.glade", NULL, E_I18N_DOMAIN);
 	dialog->gui = gui;
 
 	widget = glade_xml_get_widget(gui, "table-top");
@@ -223,18 +242,21 @@ gal_define_views_dialog_init (GalDefineViewsDialog *dialog)
 	}
 	gtk_widget_ref(widget);
 	gtk_container_remove (GTK_CONTAINER (widget->parent), widget);
+	gtk_window_set_default_size(GTK_WINDOW(dialog), 360, 270);
+	gtk_container_set_border_width(GTK_CONTAINER(dialog), 6);
 	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), widget, TRUE, TRUE, 0);
 	gtk_widget_unref(widget);
 
 	gtk_dialog_add_buttons (GTK_DIALOG (dialog),
-				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-				GTK_STOCK_OK, GTK_RESPONSE_OK,
+				GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
 				NULL);
 
 	gdvd_connect_signal(dialog, "button-new",    "clicked", G_CALLBACK(gdvd_button_new_callback));
 	gdvd_connect_signal(dialog, "button-modify", "clicked", G_CALLBACK(gdvd_button_modify_callback));
 	gdvd_connect_signal(dialog, "button-delete", "clicked", G_CALLBACK(gdvd_button_delete_callback));
+#if 0
 	gdvd_connect_signal(dialog, "button-copy",   "clicked", G_CALLBACK(gdvd_button_copy_callback));
+#endif
 
 	dialog->model = NULL;
 	etable = glade_xml_get_widget(dialog->gui, "custom-table");
@@ -243,6 +265,9 @@ gal_define_views_dialog_init (GalDefineViewsDialog *dialog)
 		g_object_set(dialog->model,
 			     "collection", dialog->collection,
 			     NULL);
+		g_signal_connect (e_table_scrolled_get_table (E_TABLE_SCROLLED (etable)),
+				  "selection_change",
+				  G_CALLBACK (etable_selection_change), dialog);
 		gtk_widget_show_all (etable);
 	}
 
@@ -280,10 +305,13 @@ gal_define_views_dialog_set_collection(GalDefineViewsDialog *dialog,
 							      collection->title);
 				gtk_label_set_text (GTK_LABEL (widget),
 						    text);
+				gtk_window_set_title (GTK_WINDOW (dialog), text);
 				g_free (text);
 			} else {
 				gtk_label_set_text (GTK_LABEL (widget),
 						    _("Define Views"));
+				gtk_window_set_title (GTK_WINDOW (dialog),
+						      _("Define Views"));
 			}
 		}
 	}
